@@ -17,6 +17,8 @@
 #include "mergeutil.h"
 #include "sortutil.h"
 
+#include "knowledgedb/airportdb.h"
+#include "knowledgedb/timezonedb.h"
 #include "knowledgedb/trainstationdb.h"
 
 #include <KItinerary/Action>
@@ -34,11 +36,7 @@
 #include <KItinerary/TrainTrip>
 #include <KItinerary/Visit>
 
-#if HAVE_KI18N_LOCALE_DATA
 #include <KCountry>
-#else
-#include <KContacts/Address>
-#endif
 
 #include <QDebug>
 #include <QJsonArray>
@@ -243,12 +241,12 @@ TrainStation ExtractorPostprocessorPrivate::processTrainStation(TrainStation sta
     } else if (id.startsWith(QLatin1String("ibnr:")) && id.size() == 12) {
         const auto record = KnowledgeDb::stationForIbnr(KnowledgeDb::IBNR{id.mid(5).toUInt()});
         applyStationData(record, station);
-        const auto country = KnowledgeDb::countryIdForUicCode(id.midRef(5, 2).toUShort()).toString();
+        const auto country = KnowledgeDb::countryIdForUicCode(QStringView(id).mid(5, 2).toUShort()).toString();
         applyStationCountry(country, station);
     } else if (id.startsWith(QLatin1String("uic:")) && id.size() == 11) {
         const auto record = KnowledgeDb::stationForUic(KnowledgeDb::UICStation{id.mid(4).toUInt()});
         applyStationData(record, station);
-        const auto country = KnowledgeDb::countryIdForUicCode(id.midRef(4, 2).toUShort()).toString();
+        const auto country = KnowledgeDb::countryIdForUicCode(QStringView(id).mid(4, 2).toUShort()).toString();
         applyStationCountry(country, station);
     } else if (id.startsWith(QLatin1String("ir:")) && id.size() > 4) {
         const auto record = KnowledgeDb::stationForIndianRailwaysStationCode(id.mid(3));
@@ -260,6 +258,16 @@ TrainStation ExtractorPostprocessorPrivate::processTrainStation(TrainStation sta
     } else if (id.startsWith(QLatin1String("vrfi:")) && id.size() >= 7 && id.size() <= 9) {
         const auto record = KnowledgeDb::stationForVRStationCode(KnowledgeDb::VRStationCode(id.mid(5)));
         applyStationData(record, station);
+    } else if (id.startsWith(QLatin1String("iata:")) && id.size() == 8) {
+        const auto iataCode = KnowledgeDb::IataCode(QStringView(id).mid(5));
+        const auto record = KnowledgeDb::stationForIataCode(iataCode);
+        applyStationData(record, station);
+        // fall back to the airport with the matching IATA code for the country information
+        // we cannot use the coordinate though, as that points to the actual airport, not the station
+        applyStationCountry(KnowledgeDb::countryForAirport(iataCode).toString(), station);
+    } else if (id.startsWith(QLatin1String("amtrak:")) && id.size() == 10) {
+        const auto record = KnowledgeDb::stationForAmtrakStationCode(KnowledgeDb::AmtrakStationCode(QStringView(id).mid(7)));
+        applyStationData(record, station);
     }
 
     return processPlace(station);
@@ -279,7 +287,7 @@ QDateTime ExtractorPostprocessorPrivate::processTrainTripTime(QDateTime dt, QDat
         return dt;
     }
 
-    const auto tz = KnowledgeDb::timezoneForLocation(station.geo().latitude(), station.geo().longitude(), station.address().addressCountry());
+    const auto tz = KnowledgeDb::timezoneForLocation(station.geo().latitude(), station.geo().longitude(), station.address().addressCountry(), station.address().addressRegion());
     if (!tz.isValid()) {
         return dt;
     }
@@ -378,7 +386,7 @@ EventReservation ExtractorPostprocessorPrivate::processEventReservation(EventRes
     return processReservation(res);
 }
 
-Event ExtractorPostprocessorPrivate::processEvent(Event event) const
+KItinerary::Event ExtractorPostprocessorPrivate::processEvent(KItinerary::Event event) const
 {
     event.setName(event.name().trimmed());
 
@@ -423,7 +431,7 @@ T ExtractorPostprocessorPrivate::processReservation(T res) const
 }
 
 
-Person ExtractorPostprocessorPrivate::processPerson(Person person) const
+KItinerary::Person ExtractorPostprocessorPrivate::processPerson(KItinerary::Person person) const
 {
     person.setName(person.name().simplified());
     person.setFamilyName(person.familyName().simplified());
@@ -452,7 +460,6 @@ PostalAddress ExtractorPostprocessorPrivate::processAddress(PostalAddress addr,
 {
     // convert to ISO 3166-1 alpha-2 country codes
     if (addr.addressCountry().size() > 2) {
-#if HAVE_KI18N_LOCALE_DATA
         QString alpha2Code;
 
         // try ISO 3166-1 alpha-3, we get that e.g. from Flixbus
@@ -465,19 +472,6 @@ PostalAddress ExtractorPostprocessorPrivate::processAddress(PostalAddress addr,
         if (!alpha2Code.isEmpty()) {
             addr.setAddressCountry(alpha2Code);
         }
-#else
-        const auto isoCode = KContacts::Address::countryToISO(addr.addressCountry()).toUpper();
-        if (!isoCode.isEmpty()) {
-            addr.setAddressCountry(isoCode);
-
-        // try ISO 3166-1 alpha-3, we get that e.g. from Flixbus
-        } else if (addr.addressCountry().size() == 3) {
-            const auto c = KnowledgeDb::countryIdFromIso3166_1alpha3(KnowledgeDb::CountryId3(addr.addressCountry()));
-            if (c.isValid()) {
-                addr.setAddressCountry(c.toString());
-            }
-        }
-#endif
     }
 
     // upper case country codes
@@ -507,7 +501,7 @@ PostalAddress ExtractorPostprocessorPrivate::processAddress(PostalAddress addr,
 #endif
 
     if (geo.isValid() && addr.addressCountry().isEmpty()) {
-        addr.setAddressCountry(KnowledgeDb::countryForCoordinate(geo.latitude(), geo.longitude()));
+        addr.setAddressCountry(KCountry::fromLocation(geo.latitude(), geo.longitude()).alpha2());
     }
 
     addr = ExtractorUtil::extractPostalCode(addr);
@@ -588,7 +582,7 @@ QDateTime ExtractorPostprocessorPrivate::processTimeForLocation(QDateTime dt, co
         return dt;
     }
 
-    const auto tz = KnowledgeDb::timezoneForLocation(place.geo().latitude(), place.geo().longitude(), place.address().addressCountry());
+    const auto tz = KnowledgeDb::timezoneForLocation(place.geo().latitude(), place.geo().longitude(), place.address().addressCountry(), place.address().addressRegion());
     if (!tz.isValid()) {
         return dt;
     }
